==> mesian-v0.1.1.tar.bz2: mesian-v0.1.1/www-data/lib/Module.php <==
<?

class Module {

	var $item_type;
	var $test;

	var $module_path = "%s/lib/Module_%s.php";

	// set item number, item type.
	function Module ($item_type="") {
		if ($item_type) {
			$this->set($item_type);
		}
	}

	function set ($item_type) {
		$this->item_type = $item_type;
	}

	function include_module_name ($name) {
		global $global, $string;

		$mod = $global["root"] . "/module/" .
			$_SESSION["user_item_type"][$this->item_type] . "/" . $name . ".php";

		if (! file_exists($mod)) {
			$retval = false;
		} else {
			include_once $mod;

			$retval = true;
		}

		return $retval;
	}

	function include_module () {
		global $global;

		$mod = sprintf($this->module_path,
			$global["root"],
			$_SESSION["user_item_type"][$this->item_type],
			$_SESSION["user_item_type"][$this->item_type]);

		if (! file_exists($mod)) {
			$retval = false;
		} else {
			include_once $mod;

			$retval = true;
		}

		return $retval;
	}

	function return_object () {

		if (! $this->include_module()) {
			$retval = false;
		} else {
			$cmd = sprintf("\$object = new %s;",
				$_SESSION["user_item_type"][$this->item_type]);

			eval($cmd);

			if (get_class($object) == $_SESSION["user_item_type"][$this->item_type]) {
				$retval = $object;
			} else {
				$retval;
			}
		}

		return $retval;
	}

	//-------------------------------------------------- execute module.
	function execute ($name) {
		// argv is sequencial array value.

		$object = $this->return_object();

		if ($object) {
			$cmd = sprintf("return(\$object->%s());", $name);
			$retval = eval($cmd);
		} else {
			$retval = false;
		}

		return $retval;
	}

	function execute1 ($name, $argv) {

		$object = $this->return_object();
		if ($object) {
			$cmd = sprintf("return(\$object->%s(\$argv));", $name);
			$retval = eval($cmd);
		} else {
			$retval = false;
		}

		return $retval;
	}

	function execute2 ($name, $argv, $argv1) {

		$object = $this->return_object();

		if ($object) {
			$cmd = sprintf("return(\$object->%s(\$argv, \$argv1));", $name);
			$retval = eval($cmd);
		} else {
			$retval = false;
		}

		return $retval;
	}

	function execute3 ($name, $argv, $argv1, $argv2) {

		$object = $this->return_object();

		if ($object) {
			$cmd = sprintf("return(\$object->%s(\$argv, \$argv1, \$argv2));", $name);
			$retval = eval($cmd);
		} else {
			$retval = false;
		}

		return $retval;
	}

	function execute4 ($name, $argv, $argv1, $argv2, $argv3) {

		$object = $this->return_object();

		if ($object) {
			$cmd = sprintf("return(\$object->%s(\$argv, \$argv1, \$argv2, \$argv3));", $name);
			$retval = eval($cmd);
		} else {
			$retval = false;
		}

		return $retval;
	}

}

/*
Description
-----------

Author
------
 Spike^ekipS <spike@spikeekips.net>

Changelog
---------

Usage
-----

*/

?>

==> mesian-v0.1.2.tar.bz2: mesian-v0.1.2/www-data/lib/Module.php <==
<?

class Module {

	var $item_type;
	var $test;

	var $module_path_name = "Module_%s";
	var $module_name = "module_%s";

	// set item number, item type.
	function Module ($item_type="") {
		if ($item_type) {
			$this->set($item_type);
		}

		$this->module_path = "%s/lib/" . $this->module_path_name . ".php";
	}

	function set ($item_type) {
		$this->item_type = $item_type;
	}

	function include_module_name ($name) {
		global $global, $string;

		$mod = $global["root"] . "/module/" .
			$_SESSION["user_item_type"][$this->item_type] . "/" . $name . ".php";

		if (! file_exists($mod)) {
			$retval = false;
		} else {
			include_once $mod;

			$retval = true;
		}

		return $retval;
	}

	function include_module () {
		global $global;

		$mod = sprintf($this->module_path,
			$global["root"],
			$_SESSION["user_item_type"][$this->item_type]);

		if (! file_exists($mod)) {
			$retval = false;
		} else {
			include_once $mod;

			$retval = true;
		}

		return $retval;
	}

	function return_object () {

		if (! $this->include_module()) {
			$retval = false;
		} else {
			$cmd = sprintf("\$object = new Module_%s;",
				$_SESSION["user_item_type"][$this->item_type]);

			eval($cmd);

			if (get_class($object) ==
					sprintf(
						$this->module_name, $_SESSION["user_item_type"][$this->item_type]
					)
			) {
				$retval = $object;

			} else {
				$retval;
			}
		}

		return $retval;
	}

	//-------------------------------------------------- execute module.
	function execute ($name) {
		// argv is sequencial array value.

		$object = $this->return_object();

		if ($object) {
			$cmd = sprintf("return(\$object->%s());", $name);
			$retval = eval($cmd);
		} else {
			$retval = false;
		}

		return $retval;
	}

	function execute1 ($name, $argv) {

		$object = $this->return_object();
		if ($object) {
			$cmd = sprintf("return(\$object->%s(\$argv));", $name);
			$retval = eval($cmd);
		} else {
			$retval = false;
		}

		return $retval;
	}

	function execute2 ($name, $argv, $argv1) {

		$object = $this->return_object();

		if ($object) {
			$cmd = sprintf("return(\$object->%s(\$argv, \$argv1));", $name);
			$retval = eval($cmd);
		} else {
			$retval = false;
		}

		return $retval;
	}

	function execute3 ($name, $argv, $argv1, $argv2) {

		$object = $this->return_object();

		if ($object) {
			$cmd = sprintf("return(\$object->%s(\$argv, \$argv1, \$argv2));", $name);
			$retval = eval($cmd);
		} else {
			$retval = false;
		}

		return $retval;
	}

	function execute4 ($name, $argv, $argv1, $argv2, $argv3) {

		$object = $this->return_object();

		if ($object) {
			$cmd = sprintf("return(\$object->%s(\$argv, \$argv1, \$argv2, \$argv3));", $name);
			$retval = eval($cmd);
		} else {
			$retval = false;
		}

		return $retval;
	}

}

/*
Description
-----------

Author
------
 Spike^ekipS <spike@spikeekips.net>

Changelog
---------

Usage
-----

*/

?>
